@@ -11,9 +11,9 @@ sub new {
 }
 
 ### B_{i,n} are Bernstein polynomials, see bernsteinpolynomialsalgorithm.pm
-### it uses a simple xyz coordinate list as a point for the bezier curve
-### One can use this with a nested list of points
-
+### it uses a simple xyz coordinate list as a control point for the bezier curve
+### One can use this with a nested list of points (which are themselves $p->xyz)
+### see point.pm
 ### NOTE for the B. polynomials 0 <= u <= 1, in @Bin for points on the curve
 ### nth-degree Bernstein polynomial
 ### B_{i,n}(u)
@@ -24,11 +24,12 @@ sub calculate {
 
 	my $p = point->new(0,0,0);
 	my $l = length(@Pointxyz); 
+	my $s = $l-1;
 
 	while (--$l >= 0) {
-		$p->setx($p->getx + @Bin[$l]*@Pointxyz[0]);
-		$p->sety($p->gety + @Bin[$l]*@Pointxyz[1]);
-		$p->setz($p->getz + @Bin[$l]*@Pointxyz[2]);
+		$p->setx($p->getx + @Bin[$l-$s]*@{@Pointxyz[$l]}[0]);
+		$p->sety($p->gety + @Bin[$l-$s]*@{@Pointxyz[$l]}[1]);
+		$p->setz($p->getz + @Bin[$l-$s]*@{@Pointxyz[$l]}[2]);
 	}
 
 	return $p;
@@ -40,9 +41,10 @@ sub calculate_for_z_order {
 
 	my $z = 0;
 	my $l = length(@Pointxyz); 
+	my $s = $l-1;
 
 	while (--$l >= 0) {
-		$z += @Bin[$l]*@Pointzyz[2];
+		$z += @Bin[$l-$s]*@{@Pointzyz[$l]}[2];
 	}
 
 	return $z;
